@@ -630,12 +630,25 @@ class EnvironmentService:
         check()
         return make_call(environment_pb2_grpc.EnvironmentServiceStub(channel).GetEnvironment, request)
 
+    def ListRegions(self, request):
+        check()
+        return make_call(environment_pb2_grpc.EnvironmentServiceStub(channel).ListRegions, request)
+
     def GetEnvironmentRequest(self, **kwargs):
         return environment_pb2.GetEnvironmentRequest(**kwargs)
 
     def GetEnvironmentResponse(self, **kwargs):
         return environment_pb2.GetEnvironmentResponse(**kwargs)
 
+    def ListRegionsRequest(self, **kwargs):
+        return environment_pb2.ListRegionsRequest(**kwargs)
+
+    def ListRegionsResponse(self, **kwargs):
+        return environment_pb2.ListRegionsResponse(**kwargs)
+
+    def Region(self, **kwargs):
+        return environment_pb2.Region(**kwargs)
+
 
 from . import provider_pb2
 from . import provider_pb2_grpc
